You've activated the basic in-app guide. In this guide, you will learn how to use the app to build and submit a workflow of Quantum ESPRESSO calculations designed to compute the electronic structure of bulk gold. Click on Step 1: Select structure and follow the instructions to proceed.
In the structure selection step, we select a structure for the calculation in one of a several ways:

- Upload file: upload a structure file from your computer
- OPTIMADE: search for structures in the OPTIMADE database
- AiiDA database: search for structures in your AiiDA database
- From Examples: select a structure from a list of example structures

Once selected, we can view the structure in the viewer below. We can also edit the structure using the available structure editors. When done, we can choose to modify the structure label and/or provide a description. These will be attached to the input structure node in your AiiDA database.

#### Tasks

1. Click on the From examples tab
2. Click on Simple crystals
3. Select Gold from the dropdown list
4. Click the Confirm button to proceed

Warning: If the confirmed structure is not yet stored in the AiiDA database, it will be stored automatically when you proceed to the next step.
Warning: Changes after confirmation will reset the following steps.
In the configuration step, we define the workflow tasks, such as optimizing the structure geometry and/or computing certain properties. We also select in this step the parameters for the workflow calculations.

#### Tasks

1. Select Full geometry relaxation
2. Open step 2.1 for further instructions

Here we select the properties to calculate. Each property is associated with a workflow that will submit one or more calculations.

#### Tasks

1. Check Electronic band structure
2. Check Electronic projected density of states (PDOS)
3. Open step 2.2 for further instructions

Here we can customize the calculation parameters. The settings are divided into several tabs:

- Basic settings: top-level calculation settings
- Advanced settings: fine-tune the calculations
- Plugin settings: parameters for plugin calculations including electronic band structure or projected density of states

Note that the app pre-configures defaults for most parameters.
See further instructions in the Basic settings panel below.
The basic settings panel provides top-level calculation settings including the electronic and magnetic properties of the material, and if spin-orbit coupling is to be considered. It also provides a choice of three protocols that pre-configure many calculation settings, balancing speed with accuracy.
Note: If running locally (for example, on the AiiDAlab demo server), we recommend selecting the fast protocol to reduce the computational cost.

#### Tasks

1. Select the fast protocol
2. (Optional) visit the Advanced settings panel (we will not customize them in this tutorial)
3. Switch to the Band structure tab

Here we configure the settings for computing the band structure.

#### Tasks

1. Check Fat bands calculation
2. (Optional) visit the PDOS panel (we will not customize them in this tutorial)
3. Click the Confirm button to proceed

Warning: Changes after confirmation will reset the following steps.

In the submission step, we define the computational resources to be used in the calculations. The global resources are used to define resources across all workflow calculations. Optionally, you can override the resource settings for specific calculations.

Warning: If running locally (for example, on the AiiDAlab demo server), we recommend keeping nodes and CPUs at the default minimum of 1 each.

Once the resources are defined, we can optionally customize the workflow label (pre-filled according to the settings of steps 1 & 2), as well as provide a detailed description of the workflow. Once we are ready, we can submit the workflow.

#### Tasks

1. Select 1 node and 1 CPU for each of the codes below
2. (Optional) customize the workflow label
3. (Optional) add a workflow description
4. Click the Submit button to proceed

Warning: The workflow may take a moment to submit.
In the final step, we can monitor the calculation and view its results. A summary of calculation parameters is also provided. Raw input and output files may be downloaded upon workflow completion, as well as an AiiDA archive containing the full calculation provenance.

#### Tasks

1. If not already there, switch over to the Status panel
2. In the process tree, follow (by clicking) `QeAppWorkChain -> PwRelaxWorkChain -> PwBaseWorkChain`
3. Click on `PwCalculation` to view a scrollable running log of the calculation
4. While the calculation is running, switch over to the Summary panel to view the submitted parameters
5. When ready, switch over to the Results panel for further instructions

Here in the results panel, each tab will open results pertaining to a specific calculation submitted by the workflow.
See further instructions below in the structure tab.
In the structure results panel, we can view the initial structure selected for the calculation. The panel is mostly the same as the one we saw in the structure selection step, with the notable additions of the structure node info and structure coordinates table. Most importantly, once structure relaxation is complete, the toggle button below the title will become active and allow us to switch between the initial and relaxed structure.

#### Tasks

1. Once the calculation is complete, click on View relaxed to switch to view the relaxed structure
2. Switch between the views, taking note of the differences in cell parameters (vector lengths/angles and volume) and atomic positions
3. When ready, switch over to the Electronic bands + PDOS panel

When partial results are available (when one of the bands and PDOS workflows finishes), the Load results button will become active allowing us to load the results from AiiDA.

#### Tasks

1. Once the calculation is complete, click on the Load results button to load the available results
Warning: It is possible to load results as soon as one of the two calculations is available. However, the following steps require both sets of data . Once both are available, make sure to check both bands and PDOS and click Apply selection.
2. Several controls are at your disposal for adjusting the plot. For now, group the orbitals by angular momentum
3. Identify the Au-5d states (you can also double click on Au-5d in the legend)
4. If selected, deselect the Au-5d in the legend (double click)
5. Double click on the plot to zoom out
6. Identify the Au semicore states
7. Feel free to explore further. When ready, you can continue to the post-guide exercises at the bottom of the app

#### Post-guide exercises

1. Switch back to the Summary panel of the results step
   - Download the workflow's raw data (zip file containing a folder hierarchy of the inputs and outputs)
     - Compare it against the process tree in the Status panel of the results step
     - Verify that they are the same by traversing both trees
   - (Advanced users) download the AiiDA archive
     - The archive includes the full calculation provenance and can be imported into any AiiDA instance
     - This reproduces the whole dataset on the receiving instance as if it was executed there
     - More details can be found here
2. Use the app to compute the band structure of Si
   - See if you get a band gap (DFT is not expected to predict the correct gap)
   - Verify that the valence bands are mostly of p character, while conduction bands are mostly of s character
3. Explore the AiiDA database by viewing the calculation history
   - This will open a Jupyter notebook (new tab), where you can search, filter, and sort a table of all calculations stored in the AiiDA database
   - Find your recent calculations for Au (and Si if exercise 2 was submitted)
   - Click on the id of either calculation to open it in a new instance of the app (new tab)
   - Verify that it is indeed your previously submitted calculation, results included (if available)